@@ -1,42 +1,53 @@
 /*
-SPDX-FileCopyrightText: 2011 Dmitry Risenberg <dmitry.risenberg@gmail.com>
+    SPDX-FileCopyrightText: 2011 Dmitry Risenberg <dmitry.risenberg@gmail.com>
 
-SPDX-License-Identifier: LGPL-2.0-or-later
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "interactivedifftest.h"
 
-#include <QTest>
+// lib
 #include "diffmodel.h"
 #include "diffmodellist.h"
 #include "parser.h"
+// Qt
+#include <QTest>
 
-using namespace Diff2;
+using namespace KompareDiff2;
 
-typedef QHash<int, QPair<QStringList, QStringList> > DifferenceHash;
+typedef QHash<int, QPair<QStringList, QStringList>> DifferenceHash;
 Q_DECLARE_METATYPE(DifferenceHash);
-typedef QHash<int, QPair<int, int> > LineNumberHash;
+typedef QHash<int, QPair<int, int>> LineNumberHash;
 Q_DECLARE_METATYPE(LineNumberHash);
 
-void InteractiveDiffTest::CompareDifferenceStringList(const DifferenceStringList& actual, const QStringList& expected)
+void InteractiveDiffTest::CompareDifferenceStringList(const DifferenceStringList &actual, const QStringList &expected)
 {
     DifferenceStringListConstIterator actualIter;
     QStringList::const_iterator expectedIter;
-    for (actualIter = actual.constBegin(), expectedIter = expected.constBegin(); actualIter != actual.constEnd() && expectedIter != expected.constEnd(); ++actualIter, ++expectedIter) {
+    for (actualIter = actual.constBegin(), expectedIter = expected.constBegin(); actualIter != actual.constEnd() && expectedIter != expected.constEnd();
+         ++actualIter, ++expectedIter) {
         QCOMPARE((*actualIter)->string(), *expectedIter);
     }
     if (actualIter != actual.constEnd()) {
-        QFAIL(QStringLiteral("Actual has too many items, starting with '%1', line %2").arg((*actualIter)->string()).arg(actualIter - actual.constBegin()).toLatin1().constData());
+        QFAIL(QStringLiteral("Actual has too many items, starting with '%1', line %2")
+                  .arg((*actualIter)->string())
+                  .arg(actualIter - actual.constBegin())
+                  .toLatin1()
+                  .constData());
     }
     if (expectedIter != expected.constEnd()) {
-        QFAIL(QStringLiteral("Actual has too few items, no match for '%1', line %2").arg(*expectedIter).arg(expectedIter - expected.constBegin()).toLatin1().constData());
+        QFAIL(QStringLiteral("Actual has too few items, no match for '%1', line %2")
+                  .arg(*expectedIter)
+                  .arg(expectedIter - expected.constBegin())
+                  .toLatin1()
+                  .constData());
     }
 }
 
 // The most basic test - something is actually working
 void InteractiveDiffTest::testOneLineChange()
 {
-    DiffModel* model = new DiffModel();
+    DiffModel *model = new DiffModel();
     QStringList newLines;
     newLines << "newline\n";
     QStringList oldLines;
@@ -45,7 +56,7 @@ void InteractiveDiffTest::testOneLineChange()
     QCOMPARE(model->differences()->size(), 1);
 
     QCOMPARE(model->differenceCount(), 1);
-    const Difference* diff = model->differenceAt(0);
+    const Difference *diff = model->differenceAt(0);
     CompareDifferenceStringList(diff->sourceLines(), oldLines);
     CompareDifferenceStringList(diff->destinationLines(), newLines);
     QCOMPARE(diff->type(), int(Difference::Change));
@@ -53,15 +64,16 @@ void InteractiveDiffTest::testOneLineChange()
 
 void InteractiveDiffTest::testSameLine()
 {
-    DiffModel* model = new DiffModel();
+    DiffModel *model = new DiffModel();
     QStringList newLines;
     newLines << "oldline2\n";
     QStringList oldLines;
-    oldLines << "oldline1\n" << "oldline2\n";
+    oldLines << "oldline1\n"
+             << "oldline2\n";
     model->linesChanged(oldLines, newLines, 2);
 
     QCOMPARE(model->differenceCount(), 1);
-    const Difference* diff = model->differenceAt(0);
+    const Difference *diff = model->differenceAt(0);
     CompareDifferenceStringList(diff->sourceLines(), QStringList() << "oldline1\n");
     CompareDifferenceStringList(diff->destinationLines(), QStringList());
     QCOMPARE(diff->type(), int(Difference::Delete));
@@ -72,10 +84,10 @@ void InteractiveDiffTest::testDifferenceContents()
     QFETCH(QStringList, patch);
     Parser parser(nullptr);
     bool malformed;
-    DiffModelList* models = parser.parse(patch, &malformed);
+    DiffModelList *models = parser.parse(patch, &malformed);
     QVERIFY(!malformed);
     QCOMPARE(models->size(), 1);
-    DiffModel* model = models->at(0);
+    DiffModel *model = models->at(0);
 
     QFETCH(QStringList, oldLines);
     QFETCH(QStringList, newLines);
@@ -88,7 +100,7 @@ void InteractiveDiffTest::testDifferenceContents()
 
     QFETCH(DifferenceHash, expectedDifferences);
     for (DifferenceHash::ConstIterator iter = expectedDifferences.constBegin(); iter != expectedDifferences.constEnd(); ++iter) {
-        const Difference* diff = model->differenceAt(iter.key());
+        const Difference *diff = model->differenceAt(iter.key());
         CompareDifferenceStringList(diff->sourceLines(), iter.value().first);
         CompareDifferenceStringList(diff->destinationLines(), iter.value().second);
     }
@@ -97,8 +109,8 @@ void InteractiveDiffTest::testDifferenceContents()
 void InteractiveDiffTest::testDifferenceContents_data()
 {
     QTest::addColumn<QStringList>("patch");
-    QTest::addColumn<QStringList>("oldLines");     // lines that are replaced
-    QTest::addColumn<QStringList>("newLines");     // replacement lines
+    QTest::addColumn<QStringList>("oldLines"); // lines that are replaced
+    QTest::addColumn<QStringList>("newLines"); // replacement lines
     QTest::addColumn<int>("editLineNumber");
     QTest::addColumn<bool>("isAlreadyApplied");
     QTest::addColumn<int>("expectedDifferenceCount");
@@ -106,26 +118,31 @@ void InteractiveDiffTest::testDifferenceContents_data()
 
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -1,5 +1,5 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "+insert1\n" <<
-              " efgh\n" <<
-              "-delete2\n" <<
-              "+insert2\n" <<
-              " ijkl\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -1,5 +1,5 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "+insert1\n"
+              << " efgh\n"
+              << "-delete2\n"
+              << "+insert2\n"
+              << " ijkl\n";
 
         QStringList newLines;
-        newLines << "newline1\n" << "newline2\n";
+        newLines << "newline1\n"
+                 << "newline2\n";
         QStringList oldLines;
         oldLines << "efgh\n";
         QStringList sourceLines;
-        sourceLines << "delete1\n" << "efgh\n" << "delete2\n";
+        sourceLines << "delete1\n"
+                    << "efgh\n"
+                    << "delete2\n";
         QStringList destinationLines;
-        destinationLines << "insert1\n" << "newline1\n" << "newline2\n" << "insert2\n";
+        destinationLines << "insert1\n"
+                         << "newline1\n"
+                         << "newline2\n"
+                         << "insert2\n";
         DifferenceHash expectedDifferences;
         expectedDifferences.insert(0, qMakePair(sourceLines, destinationLines));
 
@@ -133,25 +150,28 @@ void InteractiveDiffTest::testDifferenceContents_data()
     }
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -1,4 +1,4 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "-delete2\n" <<
-              "+insert1\n" <<
-              "+insert2\n" <<
-              " efgh\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -1,4 +1,4 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "-delete2\n"
+              << "+insert1\n"
+              << "+insert2\n"
+              << " efgh\n";
 
         QStringList newLines;
         newLines << "newline1\n";
         QStringList oldLines;
         oldLines << "efgh\n";
         QStringList sourceLines;
-        sourceLines << "delete1\n" << "delete2\n" << "efgh\n";
+        sourceLines << "delete1\n"
+                    << "delete2\n"
+                    << "efgh\n";
         QStringList destinationLines;
-        destinationLines << "insert1\n" << "insert2\n" << "newline1\n";
+        destinationLines << "insert1\n"
+                         << "insert2\n"
+                         << "newline1\n";
         DifferenceHash expectedDifferences;
         expectedDifferences.insert(0, qMakePair(sourceLines, destinationLines));
 
@@ -160,14 +180,13 @@ void InteractiveDiffTest::testDifferenceContents_data()
     }
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -1,3 +1,3 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "+insert1\n" <<
-              " efgh\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -1,3 +1,3 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "+insert1\n"
+              << " efgh\n";
 
         QStringList newLines;
         newLines << "delete1\n";
@@ -177,33 +196,32 @@ void InteractiveDiffTest::testDifferenceContents_data()
     }
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -1,3 +1,2 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              " efgh\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -1,3 +1,2 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << " efgh\n";
 
         QStringList newLines;
-        newLines << "abcd\n" << "delete1\n";
+        newLines << "abcd\n"
+                 << "delete1\n";
         QStringList oldLines;
         oldLines << "abcd\n";
         QTest::newRow("Revert deletion") << patch << oldLines << newLines << 1 << true << 0 << DifferenceHash();
     }
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -1,4 +1,5 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "-delete2\n" <<
-              "+insert1\n" <<
-              "+insert2\n" <<
-              "+insert3\n" <<
-              " efgh\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -1,4 +1,5 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "-delete2\n"
+              << "+insert1\n"
+              << "+insert2\n"
+              << "+insert3\n"
+              << " efgh\n";
 
         QStringList newLines;
         newLines << "delete2\n";
@@ -217,25 +235,32 @@ void InteractiveDiffTest::testDifferenceContents_data()
     }
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -1,4 +1,4 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "-delete2\n" <<
-              "+insert1\n" <<
-              "+insert2\n" <<
-              " efgh\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -1,4 +1,4 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "-delete2\n"
+              << "+insert1\n"
+              << "+insert2\n"
+              << " efgh\n";
 
         QStringList newLines;
-        newLines << "newline1\n" << "newline2\n";
+        newLines << "newline1\n"
+                 << "newline2\n";
         QStringList oldLines;
-        oldLines << "abcd\n" << "insert1\n" << "insert2\n" << "efgh\n";
+        oldLines << "abcd\n"
+                 << "insert1\n"
+                 << "insert2\n"
+                 << "efgh\n";
         QStringList sourceLines;
-        sourceLines << "abcd\n" << "delete1\n" << "delete2\n" << "efgh\n";
+        sourceLines << "abcd\n"
+                    << "delete1\n"
+                    << "delete2\n"
+                    << "efgh\n";
         QStringList destinationLines;
-        destinationLines << "newline1\n" << "newline2\n";
+        destinationLines << "newline1\n"
+                         << "newline2\n";
         DifferenceHash expectedDifferences;
         expectedDifferences.insert(0, qMakePair(sourceLines, destinationLines));
 
@@ -244,25 +269,30 @@ void InteractiveDiffTest::testDifferenceContents_data()
     }
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -1,4 +1,4 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "-delete2\n" <<
-              "+insert1\n" <<
-              "+insert2\n" <<
-              " efgh\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -1,4 +1,4 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "-delete2\n"
+              << "+insert1\n"
+              << "+insert2\n"
+              << " efgh\n";
 
         QStringList newLines;
-        newLines << "newline1\n" << "newline2\n";
+        newLines << "newline1\n"
+                 << "newline2\n";
         QStringList oldLines;
-        oldLines << "insert2\n" << "efgh\n";
+        oldLines << "insert2\n"
+                 << "efgh\n";
         QStringList sourceLines;
-        sourceLines << "delete1\n" << "delete2\n" << "efgh\n";
+        sourceLines << "delete1\n"
+                    << "delete2\n"
+                    << "efgh\n";
         QStringList destinationLines;
-        destinationLines << "insert1\n" << "newline1\n" << "newline2\n";
+        destinationLines << "insert1\n"
+                         << "newline1\n"
+                         << "newline2\n";
         DifferenceHash expectedDifferences;
         expectedDifferences.insert(0, qMakePair(sourceLines, destinationLines));
 
@@ -271,13 +301,12 @@ void InteractiveDiffTest::testDifferenceContents_data()
     }
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -1,2 +1,3 @@\n" <<
-              " abcd\n" <<
-              "+\n" <<
-              " efgh\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -1,2 +1,3 @@\n"
+              << " abcd\n"
+              << "+\n"
+              << " efgh\n";
 
         QStringList newLines;
         newLines << "a\n";
@@ -290,22 +319,21 @@ void InteractiveDiffTest::testDifferenceContents_data()
     }
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -1,3 +1,3 @@\n" <<
-              " abcd\n" <<
-              "+insert1\n" <<
-              "+insert2\n" <<
-              "+insert3\n" <<
-              "+insert4\n" <<
-              "+insert5\n" <<
-              " efgh\n" <<
-              "@@ -10,3 +15,3 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "+insert1\n" <<
-              " efgh\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -1,3 +1,3 @@\n"
+              << " abcd\n"
+              << "+insert1\n"
+              << "+insert2\n"
+              << "+insert3\n"
+              << "+insert4\n"
+              << "+insert5\n"
+              << " efgh\n"
+              << "@@ -10,3 +15,3 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "+insert1\n"
+              << " efgh\n";
 
         QStringList newLines;
         newLines << "newline1\n";
@@ -321,35 +349,36 @@ void InteractiveDiffTest::testDifferenceContents_data()
 void InteractiveDiffTest::testLineNumbers_data()
 {
     QTest::addColumn<QStringList>("patch");
-    QTest::addColumn<QStringList>("oldLines");     // lines that are replaced
-    QTest::addColumn<QStringList>("newLines");     // replacement lines
+    QTest::addColumn<QStringList>("oldLines"); // lines that are replaced
+    QTest::addColumn<QStringList>("newLines"); // replacement lines
     QTest::addColumn<int>("editLineNumber");
     QTest::addColumn<int>("expectedDifferenceCount");
     QTest::addColumn<LineNumberHash>("expectedLineNumbers");
 
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -1,4 +1,6 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "-delete2\n" <<
-              "+insert1\n" <<
-              "+insert2\n" <<
-              "+insert3\n" <<
-              "+insert4\n" <<
-              " efgh\n" <<
-              "@@ -15,3 +17,4 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "+insert1\n" <<
-              "+insert2\n" <<
-              " efgh\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -1,4 +1,6 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "-delete2\n"
+              << "+insert1\n"
+              << "+insert2\n"
+              << "+insert3\n"
+              << "+insert4\n"
+              << " efgh\n"
+              << "@@ -15,3 +17,4 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "+insert1\n"
+              << "+insert2\n"
+              << " efgh\n";
 
         QStringList newLines;
-        newLines << "newline1\n" << "newline2\n" << "newline2\n";
+        newLines << "newline1\n"
+                 << "newline2\n"
+                 << "newline2\n";
         QStringList oldLines;
         oldLines << "oldline1\n";
         LineNumberHash expectedLineNumbers;
@@ -359,24 +388,23 @@ void InteractiveDiffTest::testLineNumbers_data()
     }
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -1,4 +1,6 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "-delete2\n" <<
-              "+insert1\n" <<
-              "+insert2\n" <<
-              "+insert3\n" <<
-              "+insert4\n" <<
-              " efgh\n" <<
-              "@@ -15,3 +17,4 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "+insert1\n" <<
-              "+insert2\n" <<
-              " efgh\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -1,4 +1,6 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "-delete2\n"
+              << "+insert1\n"
+              << "+insert2\n"
+              << "+insert3\n"
+              << "+insert4\n"
+              << " efgh\n"
+              << "@@ -15,3 +17,4 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "+insert1\n"
+              << "+insert2\n"
+              << " efgh\n";
 
         QStringList newLines;
         newLines << "newline1\n";
@@ -390,24 +418,23 @@ void InteractiveDiffTest::testLineNumbers_data()
     }
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -1,4 +1,6 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "-delete2\n" <<
-              "+insert1\n" <<
-              "+insert2\n" <<
-              "+insert3\n" <<
-              "+insert4\n" <<
-              " efgh\n" <<
-              "@@ -15,3 +17,4 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "+insert1\n" <<
-              "+insert2\n" <<
-              " efgh\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -1,4 +1,6 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "-delete2\n"
+              << "+insert1\n"
+              << "+insert2\n"
+              << "+insert3\n"
+              << "+insert4\n"
+              << " efgh\n"
+              << "@@ -15,3 +17,4 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "+insert1\n"
+              << "+insert2\n"
+              << " efgh\n";
 
         QStringList newLines;
         newLines << "newline1\n";
@@ -421,16 +448,15 @@ void InteractiveDiffTest::testLineNumbers_data()
     }
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -10,4 +10,4 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "-delete2\n" <<
-              "+insert1\n" <<
-              "+insert2\n" <<
-              " efgh\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -10,4 +10,4 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "-delete2\n"
+              << "+insert1\n"
+              << "+insert2\n"
+              << " efgh\n";
 
         QStringList newLines;
         newLines << "newline1\n";
@@ -444,29 +470,28 @@ void InteractiveDiffTest::testLineNumbers_data()
     }
     {
         QStringList patch;
-        patch <<
-              "--- file1\t2011-01-01 20:23:45.000000000 +0300\n" <<
-              "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n" <<
-              "@@ -1,3 +1,4 @@\n" <<
-              " abcd\n" <<
-              "-delete1\n" <<
-              "+insert1\n" <<
-              "+insert2\n" <<
-              " efgh\n" <<
-              "@@ -11,4 +12,5 @@\n" <<
-              " abcd\n" <<
-              "-delete2\n" <<
-              "-delete3\n" <<
-              "+insert3\n" <<
-              "+insert4\n" <<
-              "+insert5\n" <<
-              " efgh\n" <<
-              "@@ -21,4 +23,3 @@\n" <<
-              " abcd\n" <<
-              "-delete4\n" <<
-              "-delete5\n" <<
-              "+insert6\n" <<
-              " efgh\n";
+        patch << "--- file1\t2011-01-01 20:23:45.000000000 +0300\n"
+              << "+++ file2\t2011-01-01 20:24:02.000000000 +0300\n"
+              << "@@ -1,3 +1,4 @@\n"
+              << " abcd\n"
+              << "-delete1\n"
+              << "+insert1\n"
+              << "+insert2\n"
+              << " efgh\n"
+              << "@@ -11,4 +12,5 @@\n"
+              << " abcd\n"
+              << "-delete2\n"
+              << "-delete3\n"
+              << "+insert3\n"
+              << "+insert4\n"
+              << "+insert5\n"
+              << " efgh\n"
+              << "@@ -21,4 +23,3 @@\n"
+              << " abcd\n"
+              << "-delete4\n"
+              << "-delete5\n"
+              << "+insert6\n"
+              << " efgh\n";
 
         QStringList newLines;
         newLines << "delete2\n";
@@ -487,10 +512,10 @@ void InteractiveDiffTest::testLineNumbers()
     QFETCH(QStringList, patch);
     Parser parser(nullptr);
     bool malformed;
-    DiffModelList* models = parser.parse(patch, &malformed);
+    DiffModelList *models = parser.parse(patch, &malformed);
     QVERIFY(!malformed);
     QCOMPARE(models->size(), 1);
-    DiffModel* model = models->at(0);
+    DiffModel *model = models->at(0);
     model->applyAllDifferences(true);
 
     QFETCH(QStringList, oldLines);
@@ -502,7 +527,7 @@ void InteractiveDiffTest::testLineNumbers()
 
     QFETCH(LineNumberHash, expectedLineNumbers);
     for (LineNumberHash::ConstIterator iter = expectedLineNumbers.constBegin(); iter != expectedLineNumbers.constEnd(); ++iter) {
-        const Difference* diff = model->differenceAt(iter.key());
+        const Difference *diff = model->differenceAt(iter.key());
         QCOMPARE(diff->sourceLineNumber(), iter.value().first);
         QCOMPARE(diff->trackingDestinationLineNumber(), iter.value().second);
     }
@@ -511,11 +536,11 @@ void InteractiveDiffTest::testLineNumbers()
 // When the new diff and an existing unapplied one are on neighbour lines, do not merge the unapplied with the new.
 void InteractiveDiffTest::testAppliedTouch()
 {
-    Difference* first = new Difference(2, 2);
+    Difference *first = new Difference(2, 2);
     first->addSourceLine(QString("delete1"));
     first->addDestinationLine(QString("insert1"));
     first->apply(false);
-    Difference* second = new Difference(4, 4);
+    Difference *second = new Difference(4, 4);
     second->addSourceLine(QString("delete2"));
     second->addDestinationLine(QString("insert2"));
     second->apply(false);
@@ -531,13 +556,13 @@ void InteractiveDiffTest::testAppliedTouch()
 // When the new diff and an existing unapplied one intersect, the unapplied one should be removed
 void InteractiveDiffTest::testAppliedIntersect()
 {
-    Difference* first = new Difference(2, 2);
+    Difference *first = new Difference(2, 2);
     first->addSourceLine(QString("delete1"));
     first->addSourceLine(QString("delete2"));
     first->addDestinationLine(QString("insert1"));
     first->addDestinationLine(QString("insert2"));
     first->apply(false);
-    Difference* second = new Difference(5, 5);
+    Difference *second = new Difference(5, 5);
     second->addSourceLine(QString("delete3"));
     second->addSourceLine(QString("delete4"));
     second->addDestinationLine(QString("insert3"));
@@ -547,12 +572,14 @@ void InteractiveDiffTest::testAppliedIntersect()
     model.addDiff(first);
     model.addDiff(second);
     QStringList removedLines;
-    removedLines << "delete2\n" << "oldline1\n" << "delete3\n";
+    removedLines << "delete2\n"
+                 << "oldline1\n"
+                 << "delete3\n";
     QStringList insertedLines;
     insertedLines << "newline1\n";
     model.linesChanged(removedLines, insertedLines, 3);
     QCOMPARE(model.differenceCount(), 1);
-    const Difference* newDiff = model.differenceAt(0);
+    const Difference *newDiff = model.differenceAt(0);
     QCOMPARE(newDiff->applied(), true);
     QCOMPARE(newDiff->sourceLineNumber(), 3);
     QCOMPARE(newDiff->trackingDestinationLineNumber(), 3);
@@ -562,11 +589,11 @@ void InteractiveDiffTest::testAppliedIntersect()
 
 void InteractiveDiffTest::testExistingAndApplied()
 {
-    Difference* first = new Difference(2, 2);
+    Difference *first = new Difference(2, 2);
     first->addSourceLine(QString("delete1"));
     first->addDestinationLine(QString("insert1"));
     first->apply(true);
-    Difference* second = new Difference(3, 3);
+    Difference *second = new Difference(3, 3);
     second->addSourceLine(QString("delete2"));
     second->addDestinationLine(QString("insert2"));
     second->apply(false);
@@ -585,7 +612,7 @@ void InteractiveDiffTest::testExistingAndApplied()
 
 void InteractiveDiffTest::testOneLineDeletionUnapplied()
 {
-    Difference* unappliedDeletion = new Difference(1, 1);
+    Difference *unappliedDeletion = new Difference(1, 1);
     unappliedDeletion->addSourceLine("delete1\n");
     unappliedDeletion->apply(false);
     DiffModel model;
@@ -596,7 +623,7 @@ void InteractiveDiffTest::testOneLineDeletionUnapplied()
     insertedLines << "newline1\n";
     model.linesChanged(removedLines, insertedLines, 1);
     QCOMPARE(model.differenceCount(), 1);
-    const Difference* actual = model.differenceAt(0);
+    const Difference *actual = model.differenceAt(0);
     CompareDifferenceStringList(actual->sourceLines(), removedLines);
     CompareDifferenceStringList(actual->destinationLines(), insertedLines);
 }
@@ -604,44 +631,43 @@ void InteractiveDiffTest::testOneLineDeletionUnapplied()
 void InteractiveDiffTest::testApplyUnapply()
 {
     QStringList patch;
-    patch <<
-          "--- file1\t2011-01-01 20:23:45 +0300\n" <<
-          "+++ file2\t2011-01-01 20:24:02 +0300\n" <<
-          "@@ -1,3 +1,4 @@\n" <<
-          " line1\n" <<
-          "-delete1\n" <<
-          "+insert1\n" <<
-          "+insert2\n" <<
-          " line2\n" <<
-          "@@ -11,4 +12,5 @@\n" <<
-          " line3\n" <<
-          "-delete2\n" <<
-          "-delete3\n" <<
-          "+insert3\n" <<
-          "+insert4\n" <<
-          "+insert5\n" <<
-          " line4\n" <<
-          "@@ -21,4 +23,2 @@\n" <<
-          " line5\n" <<
-          "-delete4\n" <<
-          "-delete5\n" <<
-          " line6\n" <<
-          "@@ -31,3 +31,3 @@\n" <<
-          " line7\n" <<
-          "-delete6\n" <<
-          "+insert6\n" <<
-          " line8\n";
+    patch << "--- file1\t2011-01-01 20:23:45 +0300\n"
+          << "+++ file2\t2011-01-01 20:24:02 +0300\n"
+          << "@@ -1,3 +1,4 @@\n"
+          << " line1\n"
+          << "-delete1\n"
+          << "+insert1\n"
+          << "+insert2\n"
+          << " line2\n"
+          << "@@ -11,4 +12,5 @@\n"
+          << " line3\n"
+          << "-delete2\n"
+          << "-delete3\n"
+          << "+insert3\n"
+          << "+insert4\n"
+          << "+insert5\n"
+          << " line4\n"
+          << "@@ -21,4 +23,2 @@\n"
+          << " line5\n"
+          << "-delete4\n"
+          << "-delete5\n"
+          << " line6\n"
+          << "@@ -31,3 +31,3 @@\n"
+          << " line7\n"
+          << "-delete6\n"
+          << "+insert6\n"
+          << " line8\n";
     Parser parser(nullptr);
     bool malformed;
-    DiffModelList* models = parser.parse(patch, &malformed);
+    DiffModelList *models = parser.parse(patch, &malformed);
     QVERIFY(!malformed);
     QCOMPARE(models->size(), 1);
-    DiffModel* model = models->at(0);
+    DiffModel *model = models->at(0);
     QCOMPARE(model->differenceCount(), 4);
     model->applyAllDifferences(true);
 
     const auto differences = *model->differences();
-    for (Difference* diff : differences) {
+    for (Difference *diff : differences) {
         QVERIFY(diff->applied());
     }
     model->applyAllDifferences(false);
@@ -717,56 +743,66 @@ void InteractiveDiffTest::testApplyUnapply()
     QCOMPARE(model->differenceAt(3)->trackingDestinationLineNumber(), 32);
 }
 
-static void
-contextDiff1()
+static void contextDiff1()
 {
     QStringList patch;
-    patch <<
-          "commit 7377fcc682e85ef9784adb2a2da2c8c6756f9018 (HEAD, KDE/4.11)\n" <<
-          "Author:     Dr. Chocholoušek <bla@zin.ec>\n" <<
-          "AuthorDate: Sat Jan 25 17:30:01 2014 +0100\n" <<
-          "\n" <<
-          "    Fake diff.\n" <<
-          "\n" <<
-          "diff --git a/libdiff2/diffmodel.cpp b/libdiff2/diffmodel.cpp\n" <<
-          "new file mode 100644\n" <<
-          "index a42e82d..a8da0c9\n" <<
-          "*** a/libdiff2/diffmodel.cpp\n" <<  // note the missing timestamps
-          "--- b/libdiff2/diffmodel.cpp\n" <<
-          "*************** DiffModel::DiffModel() :\n" <<
-          "*** 58,64 ****\n" <<
-          "  	m_sourceFile( "" ),\n" <<
-          "  	m_destinationFile( "" ),\n" <<
-          "  	m_sourceTimestamp( "" ),\n" <<
-          "! 	m_destinationTimestamp( "" ),\n" <<
-          "  	m_sourceRevision( "" ),\n" <<
-          "  	m_destinationRevision( "" ),\n" <<
-          "  	m_appliedCount( 0 ),\n" <<
-          "--- 58,64 ----\n" <<
-          "  	m_sourceFile( "" ),\n" <<
-          "  	m_destinationFile( "" ),\n" <<
-          "  	m_sourceTimestamp( "" ),\n" <<
-          "! 	m_destinationTimestamp( \"doh\" ),\n" <<
-          "  	m_sourceRevision( "" ),\n" <<
-          "  	m_destinationRevision( "" ),\n" <<
-          "  	m_appliedCount( 0 ),\n" <<
-          "*************** void DiffModel::splitSourceInPathAndFile\n" <<
-          "*** 84,89 ****\n" <<
-          "--- 84,91 ----\n" <<
-          "  	if( ( pos = m_source.lastIndexOf( \"/\" ) ) >= 0 )\n" <<
-          "  		m_sourcePath = m_source.mid( 0, pos+1 );\n" <<
-          "  \n" <<
-          "+ 	add_this;\n" <<
-          "+ \n" <<
-          "  	if( ( pos = m_source.lastIndexOf( \"/\" ) ) >= 0 )\n" <<
-          "  		m_sourceFile = m_source.mid( pos+1, m_source.length() - pos );\n" <<
-          "  	else\n";
+    patch << "commit 7377fcc682e85ef9784adb2a2da2c8c6756f9018 (HEAD, KDE/4.11)\n"
+          << "Author:     Dr. Chocholoušek <bla@zin.ec>\n"
+          << "AuthorDate: Sat Jan 25 17:30:01 2014 +0100\n"
+          << "\n"
+          << "    Fake diff.\n"
+          << "\n"
+          << "diff --git a/libdiff2/diffmodel.cpp b/libdiff2/diffmodel.cpp\n"
+          << "new file mode 100644\n"
+          << "index a42e82d..a8da0c9\n"
+          << "*** a/libdiff2/diffmodel.cpp\n"
+          << // note the missing timestamps
+        "--- b/libdiff2/diffmodel.cpp\n"
+          << "*************** DiffModel::DiffModel() :\n"
+          << "*** 58,64 ****\n"
+          << "  	m_sourceFile( "
+             " ),\n"
+          << "  	m_destinationFile( "
+             " ),\n"
+          << "  	m_sourceTimestamp( "
+             " ),\n"
+          << "! 	m_destinationTimestamp( "
+             " ),\n"
+          << "  	m_sourceRevision( "
+             " ),\n"
+          << "  	m_destinationRevision( "
+             " ),\n"
+          << "  	m_appliedCount( 0 ),\n"
+          << "--- 58,64 ----\n"
+          << "  	m_sourceFile( "
+             " ),\n"
+          << "  	m_destinationFile( "
+             " ),\n"
+          << "  	m_sourceTimestamp( "
+             " ),\n"
+          << "! 	m_destinationTimestamp( \"doh\" ),\n"
+          << "  	m_sourceRevision( "
+             " ),\n"
+          << "  	m_destinationRevision( "
+             " ),\n"
+          << "  	m_appliedCount( 0 ),\n"
+          << "*************** void DiffModel::splitSourceInPathAndFile\n"
+          << "*** 84,89 ****\n"
+          << "--- 84,91 ----\n"
+          << "  	if( ( pos = m_source.lastIndexOf( \"/\" ) ) >= 0 )\n"
+          << "  		m_sourcePath = m_source.mid( 0, pos+1 );\n"
+          << "  \n"
+          << "+ 	add_this;\n"
+          << "+ \n"
+          << "  	if( ( pos = m_source.lastIndexOf( \"/\" ) ) >= 0 )\n"
+          << "  		m_sourceFile = m_source.mid( pos+1, m_source.length() - pos );\n"
+          << "  	else\n";
     Parser parser(nullptr);
     bool malformed;
-    DiffModelList* models = parser.parse(patch, &malformed);
+    DiffModelList *models = parser.parse(patch, &malformed);
     QVERIFY(!malformed);
     QCOMPARE(models->size(), 1);
-    DiffModel* model = models->at(0);
+    DiffModel *model = models->at(0);
     QCOMPARE(model->differenceCount(), 2);
     model->applyAllDifferences(true);
     QVERIFY(model->differenceAt(0)->applied());
@@ -776,30 +812,36 @@ contextDiff1()
     QCOMPARE(model->differenceAt(1)->trackingDestinationLineNumber(), 87);
 }
 
-static void
-contextDiff2()
+static void contextDiff2()
 {
     QStringList patch;
-    patch <<
-          "*** a/libdiff2/diffmodel.cpp\n" <<
-          "--- b/libdiff2/diffmodel.cpp\n" <<
-          "***************\n" <<
-          "*** 55,60 **** DiffModel::DiffModel() :\n" << // note the  context here
-          "--- 55,61 ----\n" <<
-          "  	m_destination( "" ),\n" <<
-          "  	m_sourcePath( "" ),\n" <<
-          "  	m_destinationPath( "" ),\n" <<
-          "+ 	m_hoh ( "" );\n" <<
-          "  	m_sourceFile( "" ),\n" <<
-          "  	m_destinationFile( "" ),\n" <<
-          "  	m_sourceTimestamp( "" ),\n";
+    patch << "*** a/libdiff2/diffmodel.cpp\n"
+          << "--- b/libdiff2/diffmodel.cpp\n"
+          << "***************\n"
+          << "*** 55,60 **** DiffModel::DiffModel() :\n"
+          << // note the  context here
+        "--- 55,61 ----\n"
+          << "  	m_destination( "
+             " ),\n"
+          << "  	m_sourcePath( "
+             " ),\n"
+          << "  	m_destinationPath( "
+             " ),\n"
+          << "+ 	m_hoh ( "
+             " );\n"
+          << "  	m_sourceFile( "
+             " ),\n"
+          << "  	m_destinationFile( "
+             " ),\n"
+          << "  	m_sourceTimestamp( "
+             " ),\n";
 
     Parser parser(nullptr);
     bool malformed;
-    DiffModelList* models = parser.parse(patch, &malformed);
+    DiffModelList *models = parser.parse(patch, &malformed);
     QVERIFY(!malformed);
     QCOMPARE(models->size(), 1);
-    DiffModel* model = models->at(0);
+    DiffModel *model = models->at(0);
     QCOMPARE(model->differenceCount(), 1);
     model->applyAllDifferences(true);
     QVERIFY(model->differenceAt(0)->applied());
@@ -816,17 +858,16 @@ void InteractiveDiffTest::testContextDiff()
 void InteractiveDiffTest::testNormalDiff()
 {
     QStringList patch;
-    patch <<
-          "1c1\n" <<
-          "< a\n" <<
-          "---\n" <<
-          "> b\n";
+    patch << "1c1\n"
+          << "< a\n"
+          << "---\n"
+          << "> b\n";
     Parser parser(nullptr);
     bool malformed;
-    DiffModelList* models = parser.parse(patch, &malformed);
+    DiffModelList *models = parser.parse(patch, &malformed);
     QVERIFY(!malformed);
     QCOMPARE(models->size(), 1);
-    DiffModel* model = models->at(0);
+    DiffModel *model = models->at(0);
     QCOMPARE(model->differenceCount(), 1);
     model->applyAllDifferences(true);
     QVERIFY(model->differenceAt(0)->applied());
